# comment out when not pre-release
#define prel	        beta1

%define rel	        3

%define major		5
%define libname		%mklibname kvilib %{major}
%define develname	%mklibname kvilib -d

%ifarch %{arm} %{ix86}
%bcond_with want_qtwebengine
%else
%bcond_without want_qtwebengine
%endif

Name:		kvirc
Version:	5.2.6
Release:	%mkrel %{?prel:0.%prel.}%{rel}
Summary:	Qt IRC client
Group:		Networking/IRC
License:	GPLv2+ with exceptions
URL:		https://www.kvirc.net/
Source0:	https://github.com/kvirc/KVIrc/archive/%{version}%{?prel:-%prel}/%{name}-%{version}%{?prel:-%prel}.tar.gz
Source1:	kvirc-4.0.4-irc.protocol
Source2:	kvirc-4.0.4-irc6.protocol

# Upstream branch patches
# $ git format-patch ${version}

BuildRequires:	kf6-rpm-macros

BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qt6Concurrent)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6DBus)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Multimedia)
BuildRequires:	cmake(Qt6MultimediaWidgets)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6PrintSupport)
BuildRequires:	cmake(Qt6Sql)
BuildRequires:	cmake(Qt6Svg)
BuildRequires:	cmake(Qt6Widgets)
%if %{with want_qtwebengine}
BuildRequires:	cmake(Qt6WebEngineWidgets)
%endif
BuildRequires:	cmake(Qt6Xml)
BuildRequires:	cmake(Phonon4Qt6)

BuildRequires:	cmake(KF6CoreAddons)
BuildRequires:	cmake(KF6I18n)
BuildRequires:	cmake(KF6XmlGui)
BuildRequires:	cmake(KF6WindowSystem)
BuildRequires:	cmake(KF6Notifications)
BuildRequires:	cmake(KF6Service)
BuildRequires:	cmake(KF6KIO)
BuildRequires:	cmake(KF6Parts)
BuildRequires:	cmake(KF6StatusNotifierItem)

BuildRequires:	doxygen
BuildRequires:	gettext
BuildRequires:	pkgconfig(audiofile)
BuildRequires:	pkgconfig(enchant-2)
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(libv4l2)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	gsm-devel
BuildRequires:	perl-devel

Provides:	kvirc4 = %{version}-%{release}

%description
Qt5-based IRC client with support for themes, transparency, encryption,
many extended IRC features, and scripting.

%files -f %{name}.lang
%doc README.md RELEASES
%{_kf6_bindir}/%{name}
%{_kf6_libdir}/%{name}/
%{_kf6_applicationsdir}/net.%{name}.KVIrc5.desktop
%{_kf6_datadir}/pixmaps/%{name}.png
%{_kf6_services}/_irc*.protocol
%{_kf6_iconsdir}/hicolor/*/*/*.*
%{_kf6_mandir}/man1/*.1*
%dir %{_kf6_datadir}/%{name}
%dir %{_kf6_datadir}/%{name}/5.2
%dir %{_kf6_datadir}/%{name}/5.2/locale
%{_kf6_datadir}/%{name}/5.2/audio/
%{_kf6_datadir}/%{name}/5.2/config/
%{_kf6_datadir}/%{name}/5.2/defscript/
%{_kf6_datadir}/%{name}/5.2/help/
%{_kf6_datadir}/%{name}/5.2/modules/
%{_kf6_datadir}/%{name}/5.2/msgcolors/
%{_kf6_datadir}/%{name}/5.2/pics/
%{_kf6_datadir}/%{name}/5.2/themes/
%{_kf6_datadir}/%{name}/5.2/license/

# Translation man files
%lang(de) %{_kf6_mandir}/de/man1/%{name}.1.?z
%lang(fr) %{_kf6_mandir}/fr/man1/%{name}.1.?z
%lang(it) %{_kf6_mandir}/it/man1/%{name}.1.?z
%lang(pt) %{_kf6_mandir}/pt/man1/%{name}.1.?z
%lang(uk) %{_kf6_mandir}/uk/man1/%{name}.1.?z

#--------------------------------------------------------------------

%package -n %{libname}
Summary:	Shared library for KVirc
Group:		System/Libraries

%description -n %{libname}
Shared library provided by KVirc.

%files -n %{libname}
%{_kf6_libdir}/libkvilib.so.%{major}{,.*}

#--------------------------------------------------------------------

%package -n %{develname}
Summary:	Development headers for KVirc
Group:		Development/C++
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development headers for KVirc.

%files  -n %{develname}
%doc README.md RELEASES
%{_kf6_bindir}/%{name}-config
%{_kf6_libdir}/libkvilib.so

#--------------------------------------------------------------------

%prep
%autosetup -p1 -n KVIrc-%{version}%{?prel:-%prel}

%build
%cmake_kf6 \
    -DWANT_DCC_VIDEO=ON \
    -DWANT_QTWEBKIT=OFF \
    %{!?with_want_qtwebengine:-DWANT_QTWEBENGINE:BOOL=OFF} \
    -DWANT_OGG_THEORA=ON
%cmake_build

%install
%cmake_install

# Zé: irc protocol handle
install -m755 -d %{buildroot}%{_kf6_services}
install -m644 %{S:1} %{buildroot}%{_kf6_services}/_irc.protocol
install -m644 %{S:2} %{buildroot}%{_kf6_services}/_irc6.protocol

# Language files; not under /usr/share/locale, need to be handled manually
  (cd %{buildroot} && find . -name '*.mo') | sed -e 's|^.||' | sed -e \
  's:\(.*/locale/\)\([^/_]\+\)\(.*\.mo$\):%lang(\2) \1\2\3:' \
  >> %{name}.lang


%changelog
* Tue Apr 29 2025 daviddavid <daviddavid> 5.2.6-3.mga10
+ Revision: 2179806
- rebuild for new libtheora 1.2.0

* Wed Mar 05 2025 daviddavid <daviddavid> 5.2.6-2.mga10
+ Revision: 2160986
- rebuild for python 3.13

* Sun Dec 01 2024 daviddavid <daviddavid> 5.2.6-1.mga10
+ Revision: 2120535
- new version: 5.2.6

* Fri Aug 23 2024 tv <tv> 5.2.4-2.mga10
+ Revision: 2089679
- Rebuild for perl-5.40

* Tue May 14 2024 daviddavid <daviddavid> 5.2.4-1.mga10
+ Revision: 2064054
- new version: 5.2.4
- remove merged upstream patches

* Mon May 06 2024 daviddavid <daviddavid> 5.2.2-2.mga10
+ Revision: 2062612
- update staging queue as of 2024-05-04
- re-enable dcc_video now ported to Qt6

* Mon Mar 25 2024 daviddavid <daviddavid> 5.2.2-1.mga10
+ Revision: 2052151
- new version: 5.2.2
- remove merged upstream patch

* Sun Jan 21 2024 daviddavid <daviddavid> 5.2.0-1.mga10
+ Revision: 2033067
- new version: 5.2.0
- switch to Qt6/KF6

* Tue Dec 05 2023 daviddavid <daviddavid> 5.0.0-13.mga10
+ Revision: 2013231
- rebuild for new perl 5.38.0

* Mon Mar 20 2023 papoteur <papoteur> 5.0.0-12.mga9
+ Revision: 1949815
- disable qtwebkit

* Mon Jun 06 2022 umeabot <umeabot> 5.0.0-11.mga9
+ Revision: 1861506
- Rebuild for Perl 5.36

* Wed Apr 06 2022 umeabot <umeabot> 5.0.0-10.mga9
+ Revision: 1845911
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 5.0.0-9.mga9
+ Revision: 1747625
- rebuild for openssl 3.0.0

* Mon May 24 2021 umeabot <umeabot> 5.0.0-8.mga9
+ Revision: 1726369
- Rebuild for perl 5.34

* Thu Dec 17 2020 umeabot <umeabot> 5.0.0-7.mga8
+ Revision: 1658861
- Rebuild for new Qt5

* Thu Jun 18 2020 daviddavid <daviddavid> 5.0.0-6.mga8
+ Revision: 1595846
- aad upstream patch to fix build with Qt 5.15+
+ umeabot <umeabot>
- Rebuild for perl 5.32

* Sun Feb 16 2020 umeabot <umeabot> 5.0.0-5.mga8
+ Revision: 1530588
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Tue Sep 03 2019 daviddavid <daviddavid> 5.0.0-4.mga8
+ Revision: 1436662
- disable py2 support

* Tue Aug 27 2019 tmb <tmb> 5.0.0-3.mga8
+ Revision: 1433975
- rebuild for perl 5.30

* Sun Mar 31 2019 umeabot <umeabot> 5.0.0-2.mga7
+ Revision: 1382986
- Qt5 Rebuild

* Wed Jan 02 2019 daviddavid <daviddavid> 5.0.0-1.mga7
+ Revision: 1348515
- new version: 5.0.0 (final)
- now libmajor is 5
- remove merged upstream patch

* Sun Sep 23 2018 umeabot <umeabot> 5.0.0-0.beta1.4.mga7
+ Revision: 1298686
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 pterjan <pterjan> 5.0.0-0.beta1.3.mga7
+ Revision: 1248925
- Rebuild for perl 5.28

* Thu Jun 07 2018 daviddavid <daviddavid> 5.0.0-0.beta1.2.mga7
+ Revision: 1235088
- add upstream patch to fix build with new Qt5 >= 5.11.0

* Mon Apr 30 2018 daviddavid <daviddavid> 5.0.0-0.beta1.1.mga7
+ Revision: 1223838
- new version: 5.0.0_beta1

* Wed Nov 22 2017 tv <tv> 5.0.0-0.alpha2.6.mga7
+ Revision: 1178689
- rebuild for new openssl

* Wed Oct 04 2017 daviddavid <daviddavid> 5.0.0-0.alpha2.5.mga7
+ Revision: 1168634
- rebuild against compat-openssl10
+ pterjan <pterjan>
- Rebuild for perl ABI changes

* Sat Jul 22 2017 neoclust <neoclust> 5.0.0-0.alpha2.3.mga7
+ Revision: 1127647
- Rebuild against new Perl 5.26

* Fri Mar 10 2017 akien <akien> 5.0.0-0.alpha2.2.mga6
+ Revision: 1091615
- Rebuild for v4l-utils 1.12.3

* Mon Mar 14 2016 daviddavid <daviddavid> 5.0.0-0.alpha2.1.mga6
+ Revision: 990441
- new version: 5.0.0_alpha2

* Wed Mar 02 2016 umeabot <umeabot> 5.0.0-0.alpha1.2.mga6
+ Revision: 983559
- Rebuild for openssl

* Sat Feb 13 2016 daviddavid <daviddavid> 5.0.0-0.alpha1.1.mga6
+ Revision: 959558
- new version: 5.0.0_alpha1 based on KF5
- switch build to Qt5/kf5
- update Source URL
- add audiofile and enchant support
- fix file-not-in-%%lang warning

* Tue Oct 27 2015 daviddavid <daviddavid> 4.2.0-9.mga6
+ Revision: 895877
- remove empty lang files to fix build with latest rpm

* Sat Jun 27 2015 tv <tv> 4.2.0-8.mga6
+ Revision: 846154
- rebuild with soname-ified perl

* Wed Oct 15 2014 umeabot <umeabot> 4.2.0-7.mga5
+ Revision: 741609
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.2.0-6.mga5
+ Revision: 681241
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 4.2.0-5.mga4
+ Revision: 528157
- Mageia 4 Mass Rebuild

* Sun Jun 16 2013 fwang <fwang> 4.2.0-4.mga4
+ Revision: 443601
- add more br

* Sun Jun 16 2013 fwang <fwang> 4.2.0-3.mga4
+ Revision: 443597
- add fedora patches

* Sat Mar 30 2013 tmb <tmb> 4.2.0-3.mga3
+ Revision: 406683
- rebuild for new perl (#9570)

* Sat Jan 12 2013 umeabot <umeabot> 4.2.0-2.mga3
+ Revision: 356573
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 29 2012 juancho <juancho> 4.2.0-1.mga3
+ Revision: 322936
- Updated to 4.2.0

* Sat Aug 11 2012 pterjan <pterjan> 4.1.3-0.svn6163.2.mga3
+ Revision: 280489
- Rebuild for new perl

* Tue May 01 2012 sander85 <sander85> 4.1.3-0.svn6163.1.mga2
+ Revision: 234450
- upgrade to newer revision to fix glitches in input fields

* Thu Dec 22 2011 juancho <juancho> 4.1.3-0.svn5993.1.mga2
+ Revision: 185674
- Updated to 4.1.3 (svnrev 5993)
- Fixed man pages, removed hardcoded installation
- Enabled cmake options WANT_DCC_VIDEO and WANT_OGG_THEORA
- Fixed broken install of _irc*.protocol services
- Removed BuildRoot stuff
+ ze <ze>
- add irc handle
- rebuild against new perl version
- clean devel requires to %%release

* Mon Jun 13 2011 ze <ze> 4.0.4-2.mga2
+ Revision: 105559
- add requires for lib package

* Sat May 14 2011 ze <ze> 4.0.4-1.mga2
+ Revision: 98776
- imported package kvirc

